
set mem 300m
set more off
version 10

* set directory where files are located
cd "D:\Data\Comparitive Election Studies\Comparitive Study of Electoral Systems\Mike\Replication"
*cd "/Users/markkayser/Dropbox/_Projects/_OldStuff/Benchvote/_Replication/_Benchmarking_Replication"


** Aggregate Data Results **
use Benchmarking_Agg_Data.dta

** Figure 1 -- Scatterplot **
* note: figure in paper was prepared in R for better visuals *

* panel 1 *
graph twoway (lfit votelead gr_loc_pc_an) (scatter votelead gr_loc_pc_an), name(fig1pan1)

* panel 2 *
graph twoway (lfit votelead gr_glob_pc_an) (scatter votelead gr_glob_pc_an), name(fig1pan2)

* panel 3 *
graph twoway (lfit votelead unem_loc_pc_an) (scatter votelead unem_loc_pc_an), name(fig1pan3)

* panel 4 *
graph twoway (lfit votelead unem_glob_pc_an) (scatter votelead unem_glob_pc_an), name(fig1pan4)

** Table 1 -- Main Aggregate Results **

* column 1 *
reg votelead gr_an unem_an, robust

* column 2 *
reg votelead gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an, robust
test gr_loc_med_an = gr_glob_med_an
test unem_loc_med_an = unem_glob_med_an

* column 3 *
reg votelead gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an, robust
test gr_loc_pc_an = gr_glob_pc_an
test unem_loc_pc_an = unem_glob_pc_an

* column 4 *
reg votelead gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an, robust
test gr_loc_tr_an = gr_glob_tr_an
test unem_loc_tr_an = unem_glob_tr_an

** Table 2 -- Comparison of Model Fit **

* make sure model comparisons are made on common sample
gen comsamp=1 if gr_an!=. & gr_loc_med_an!=. & gr_loc_pc_an!=. & gr_loc_tr_an!=. & unem_an!=. & unem_loc_med_an!=. & unem_loc_pc_an!=. & unem_loc_tr_an!=.

reg votelead gr_an unem_an if comsamp==1, robust
estat ic
reg votelead gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an if comsamp==1, robust
estat ic
reg votelead gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an if comsamp==1, robust
estat ic
reg votelead gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an if comsamp==1, robust
estat ic
reg votelead gr_loc_med_an unem_an if comsamp==1, robust
estat ic
reg votelead gr_loc_pc_an unem_an if comsamp==1, robust
estat ic
reg votelead gr_loc_tr_an unem_an if comsamp==1, robust
estat ic
reg votelead gr_loc_med_an unem_loc_med_an if comsamp==1, robust
estat ic
reg votelead gr_loc_pc_an unem_loc_pc_an if comsamp==1, robust
estat ic
reg votelead gr_loc_tr_an unem_loc_tr_an if comsamp==1, robust
estat ic

** Table 3 -- Robustness Check for Aggregate-level Models **

* with controls *

* column 1 *
reg votelead gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an coalsize enep pop elecyr, robust

* column 2 *
reg votelead gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an coalsize enep pop elecyr, robust

* column 3 *
reg votelead gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an coalsize enep pop elecyr, robust

* with controls and LDVs *

* column 4 *
reg votelead votelead_m1 gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an coalsize enep pop elecyr, robust

* column 5 *
reg votelead votelead_m1 gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an coalsize enep pop elecyr, robust

* column 6 *
reg votelead votelead_m1 gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an coalsize enep pop elecyr, robust

* with controls, LDVs, and FEs *

* column 7 *
xtreg votelead votelead_m1 gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an coalsize enep pop elecyr, fe robust i(ccode)

* column 8 *
xtreg votelead votelead_m1 gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an coalsize enep pop elecyr, fe robust i(ccode)

* column 9 *
xtreg votelead votelead_m1 gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an coalsize enep pop elecyr, fe robust i(ccode)

** Figure 2 -- Benchmarking Over Time **

* 10 year moving window *
gen start = 0
gen end = 0
gen beta_gr = .
gen beta_gr_loc = .
gen window_end = .
local window = 10
set more off
forvalues y = 1/20 {

replace start = `y' + 1979 in `y'
replace end = start + `window' in `y'
local a = 1979 + `y'
local b = 1979 + `y' + `window'
reg votelead gr_an unem_an if elecyr >= `a' & elecyr < `b'
replace beta_gr = _b[gr_an] in `y'
reg votelead gr_loc_pc_an unem_an if elecyr >= `a' & elecyr <`b'
replace beta_gr_loc = _b[gr_loc_pc_an] in `y'
replace window_end = `b' in `y'

}

sort elecyr
line beta_gr beta_gr_loc window_end, legend(off) ytitle(Coefficient) xtitle(Window End)yline(0) clpattern(solid shortdash) clcolor (black black) scheme(s1mono) name(fig2)

drop start
drop end
drop beta_gr
drop beta_gr_loc
drop window_end 

** Table 4 -- Government Types **

* column 1 *
reg votelead gr_an unem_an if mingov_in_nl==1, r

* column 2 *
reg votelead gr_an unem_an if typgob2==3, r

* column 3 *
reg votelead gr_an unem_an if typgob2==1, r
 
* column 4 *
reg votelead gr_loc_pc_an unem_an if mingov_in_nl==1, r

* column 5 *
reg votelead gr_loc_pc_an unem_an if typgob2==3, r

* column 6 *
reg votelead gr_loc_pc_an unem_an if typgob2==1, r

** Individual Data Results **
clear matrix
clear
use Benchmarking_Ind_Data.dta
gen country = substr(elecstud,1,3)
gen outside = (party==0)

** Table 5 -- Invidual Level Results **
* note: marginal effects were calculated by the authors using a c++ program, not provided here *

* create variables for table *
gen gr_lead = gr * lead
gen unem_lead = unem * lead
gen gr_loc_md_lead = gr_loc_md * lead
gen gr_loc_pc_lead = gr_loc_pc * lead
gen gr_loc_tr_lead = gr_loc_tr * lead
gen gr_glob_md_lead = gr_glob_md * lead
gen gr_glob_pc_lead = gr_glob_pc * lead
gen gr_glob_tr_lead = gr_glob_tr * lead
gen unem_loc_md_lead = unem_loc_md * lead
gen unem_loc_pc_lead = unem_loc_pc * lead
gen unem_loc_tr_lead = unem_loc_tr * lead
gen unem_glob_md_lead = unem_glob_md * lead
gen unem_glob_pc_lead = unem_glob_pc * lead
gen unem_glob_tr_lead = unem_glob_tr * lead

* column 1 *
clogit votemulti outside lead dist gr_lead unem_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 2 *
clogit votemulti outside lead dist gr_loc_md_lead gr_glob_md_lead unem_loc_md_lead unem_glob_md_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 3 *
clogit votemulti outside lead dist gr_loc_pc_lead gr_glob_pc_lead unem_loc_pc_lead unem_glob_pc_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 4 *
clogit votemulti outside lead dist gr_loc_tr_lead gr_glob_tr_lead unem_loc_tr_lead unem_glob_tr_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

** Table 6 -- Invidual Level Robustness Checks **

* create variables for table *
gen idf1 = id_family == 1
gen idf2 = id_family == 2
gen idf3 = id_family == 3
gen idf4 = id_family == 4
gen idf5 = id_family == 5
gen idf6 = id_family == 6
gen idf7 = id_family == 7
gen idf8 = id_family == 8
gen idf9 = id_family == 9
gen idf10 = id_family == 10
gen idf13 = id_family == 13
gen year_founded_sq = year_founded^2

gen gender_lead = gender * lead
gen age_lead = age * lead
gen income_lead = income * lead
gen educ_lead = educ * lead

gen idf1_gender = idf1 * gender
gen idf2_gender = idf2 * gender
gen idf3_gender = idf3 * gender
gen idf4_gender = idf4 * gender
gen idf5_gender = idf5 * gender
gen idf6_gender = idf6 * gender
gen idf7_gender = idf7 * gender
gen idf8_gender = idf8 * gender
gen idf9_gender = idf9 * gender
gen idf10_gender = idf10 * gender
gen idf13_gender = idf13 * gender

gen idf1_age = idf1 * age
gen idf2_age = idf2 * age
gen idf3_age = idf3 * age
gen idf4_age = idf4 * age
gen idf5_age = idf5 * age
gen idf6_age = idf6 * age
gen idf7_age = idf7 * age
gen idf8_age = idf8 * age
gen idf9_age = idf9 * age
gen idf10_age = idf10 * age
gen idf13_age = idf13 * age

gen idf1_income = idf1 * income
gen idf2_income = idf2 * income
gen idf3_income = idf3 * income
gen idf4_income = idf4 * income
gen idf5_income = idf5 * income
gen idf6_income = idf6 * income
gen idf7_income = idf7 * income
gen idf8_income = idf8 * income
gen idf9_income = idf9 * income
gen idf10_income = idf10 * income
gen idf13_income = idf13 * income

gen idf1_educ = idf1 * educ
gen idf2_educ = idf2 * educ
gen idf3_educ = idf3 * educ
gen idf4_educ = idf4 * educ
gen idf5_educ = idf5 * educ
gen idf6_educ = idf6 * educ
gen idf7_educ = idf7 * educ
gen idf8_educ = idf8 * educ
gen idf9_educ = idf9 * educ
gen idf10_educ = idf10 * educ
gen idf13_educ = idf13 * educ

gen yf_gender = year_founded * gender
gen yf2_gender = year_founded_sq * gender

gen yf_age = year_founded * age
gen yf2_age = year_founded_sq * age

gen yf_educ = year_founded * educ
gen yf2_educ = year_founded_sq * educ

* column 1 *
set more off
clogit votemulti lead dist gr_loc_md_lead gr_glob_md_lead unem_loc_md_lead unem_glob_md_lead idf1-idf13 year_founded year_founded_sq, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 2 *
set more off
clogit votemulti lead dist gr_loc_pc_lead gr_glob_pc_lead unem_loc_pc_lead unem_glob_pc_lead idf1-idf13 year_founded year_founded_sq, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 3 *
set more off
clogit votemulti lead dist gr_loc_tr_lead gr_glob_tr_lead unem_loc_tr_lead unem_glob_tr_lead idf1-idf13 year_founded year_founded_sq, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 4 *
set more off
clogit votemulti lead dist gr_loc_md_lead gr_glob_md_lead unem_loc_md_lead unem_glob_md_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 5 *
set more off
clogit votemulti lead dist gr_loc_pc_lead gr_glob_pc_lead unem_loc_pc_lead unem_glob_pc_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 6 *
set more off
clogit votemulti lead dist gr_loc_tr_lead gr_glob_tr_lead unem_loc_tr_lead unem_glob_tr_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 7 *
set more off
clogit votemulti lead dist gr_loc_md_lead gr_glob_md_lead unem_loc_md_lead unem_glob_md_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead idf1_gender-idf13_gender idf1_age-idf13_age idf1_educ-idf13_educ yf_gender yf2_gender yf_age yf2_age yf_educ yf2_educ, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 8 *
set more off
clogit votemulti lead dist gr_loc_pc_lead gr_glob_pc_lead unem_loc_pc_lead unem_glob_pc_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead idf1_gender-idf13_gender idf1_age-idf13_age idf1_educ-idf13_educ yf_gender yf2_gender yf_age yf2_age yf_educ yf2_educ, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)

* column 9 *
set more off
clogit votemulti lead dist gr_loc_tr_lead gr_glob_tr_lead unem_loc_tr_lead unem_glob_tr_lead idf1-idf13 year_founded year_founded_sq gender_lead age_lead educ_lead idf1_gender-idf13_gender idf1_age-idf13_age idf1_educ-idf13_educ yf_gender yf2_gender yf_age yf2_age yf_educ yf2_educ, group(id) cluster(elecstud)
codebook country if e(sample)
codebook elecstud if e(sample)
codebook id if e(sample)



** Media Data Results **
clear matrix
clear
use Benchmarking_Media_Data.dta

** Table 7 -- Benchmarking of Economic News **

* column 1 *
regress news_frac_pos_q gr, robust

* column 2 *
regress news_frac_pos_q gr_loc_md gr_glob_md, robust
test gr_loc_md = gr_glob_md

* column 3 *
regress news_frac_pos_q gr_loc_pc gr_glob_pc, robust
test gr_loc_pc = gr_glob_pc

* column 4 *
regress news_frac_pos_q gr_loc_tr gr_glob_tr, robust
test gr_loc_tr = gr_glob_tr



** Financial Crisis Data Results **
clear matrix
clear
use Benchmarking_Crisis_Data.dta

** Figure 3 -- Financial Crisis **

* panel 1 *
gr twoway scatter diff_oecd gr_country if vincrease==0, yline(0) msymbol(Oh) mcolor(midblue) legend(off) xscale(range(-3 3)) xlabel(-3 -2 -1 0 1 2 3) || scatter diff_oecd gr_country if vincrease==1, msymbol(T) mlabel(country) mcolor(red) xtitle(Growth) ytitle(Deviation from OECD) name(fig3pan1)

* panel 2 *
gr twoway lfit vote_ch gr_country, legend(off) ytitle(Change in Vote Share) xtitle(Growth) lcolor(blue) lpattern(dash) xscale(range(-3 3)) xlabel(-3 -2 -1 0 1 2 3) || scatter vote_ch gr_country, msymbol(Oh) mcolor(midblue) || scatter vote_ch diff_oecd, msymbol(d) mcolor(red) || lfit vote_ch diff_oecd, lcolor(red) name(fig3pan2)



** Pricipal Components Decomposition Data Results **
clear matrix
clear
use Benchmarking_PC_Data.dta

** Figure 4 -- Factor Loadings for Priniple Components Decomposition **
* note: figure in paper was prepared in minitab for better visuals *

scatter fac2 fac1, mlabel(country) mlabsize(vsmall) name(fig4)
